@@ -5,31 +5,43 @@ use warnings;
 use LWP::UserAgent;
 use JSON::MaybeXS;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub new {
     my ( $class, %params ) = @_;
     my $self = {
         api_key  => $params{api_key} // $ENV{OPENAI_KEY},
-        endpoint => $params{endpoint} || 'https://api.openai.com/v1/',
+        endpoint => $params{endpoint} || 'https://api.openai.com/v1',
     };
     return bless $self, $class;
 }
 
 sub completions {
     my ( $self, %params ) = @_;
+    return $self->_openai_request( 'completions', \%params );
+}
+
+sub _openai_request {
+    my ( $self, $method, $params ) = @_;
+
     my $ua = LWP::UserAgent->new();
 
     my $req = HTTP::Request->new(
-        POST => "$self->{endpoint}completions",
+        POST => "$self->{endpoint}/$method",
         [
             'Content-Type'  => 'application/json',
             'Authorization' => "Bearer $self->{api_key}",
         ],
-        encode_json( \%params ),
+        encode_json($params),
     );
 
-    return $ua->request($req);
+    my $res = $ua->request($req);
+
+    if ( $res->is_success ) {
+        return decode_json( $res->decoded_content );
+    } else {
+        die "Error retrieving '$method': " . $res->status_line;
+    }
 }
 
 1;
